#delimit ;
set more off;
cap log close;
set mem 400000;

cd "E:\RA\NLSY\FINAL_FILES\";

**************************************************************************************************************
This file takes data created by _hrptojobno.do and _experience_men/_women.do and calculates 
statistics on the distribution of hourly rates of pay and experience
**************************************************************************************************************;


** Need to get the number of children a woman has at any given age
	Will use _weeklyfile2_women.dta to get it (though there are easier sources)
	Will keep number of children under 6, under 18, and everk, as well as creating
	a new variable called childstatus = 0 if never have kids, =1 if have kids at some point
	but not yet, =2 if have had children;
*****;

log using Logs\_hrpandexp_statistics.log, replace;


use "My Statistics\_weeklyfile2_women.dta", clear;

keep ID week everk nkborn nku6 nku18 ageyownk;

do "Do\agecalc.do";

gen minnku6 = nku6;
gen minnku18 = nku18;
rename nku6 maxnku6;
rename nku18 maxnku18;

sort ID week;
collapse (min) everk nkborn minnku6 minnku18 ageyownk (max) maxnku6 maxnku18, by(ID age);
sort ID age;
merge (ID age) using "My Statistics\_hrp_women_byage.dta";

tab _merge;
drop _merge;
sort ID age;

append using "My Statistics\_hrp_men_byage.dta";
sort ID age;
gen sex = 0 if SAMP<=4;
replace sex = 1 if SAMP>4;




** Generate commands common to _hrp_statistics;

gen  lavHRP = log(avHRP);
gen lmedHRP = log(medHRP);

gen childstatus = 0 if everk==0;
replace childstatus = 1 if everk==1 & nkborn==0;
replace childstatus = 2 if everk==1 & nkborn~=0 & sex==1;


* a is a count variable;
gen a = 1; 
gen  hrpgroup = 1 if avHRP>0 & avHRP<=400;
replace hrpgroup = 2 if avHRP>400 & avHRP<=800;
replace hrpgroup = 3 if avHRP>800 & avHRP<=1200;
replace hrpgroup = 4 if avHRP>1200 & avHRP<=1600;
replace hrpgroup = 5 if avHRP>1600 & avHRP<=2000;
replace hrpgroup = 6 if avHRP>2000;

label define hrpgv 1 "<=$4" 2 "$4-$8" 3 "$8-$12" 4 "$12-$16" 5 "$16-$20" 6">$20";
label values hrpgroup hrpgv;

gen a1 = 0 if age<20;
replace a1 = 1 if age>=20 & age<25;
replace a1 = 2 if age>=25 & age<30;
replace a1 = 3 if age>=30 & age<35;
replace a1 = 4 if age>=35 & age<40;
replace a1 = 5 if age>=40 & age<45;
replace a1 = 6 if age>=45;
label define a1v 1 "20-24" 2 "25-29" 3 "30-34" 4 "35-39" 5 "40-44";

label values a1 a1v;




** merging with information on experience by individual and age (note: experience at time when individual turns given age,
	wage is average for year in which individual IS a given age);
sort ID age;
merge (ID age) using "My Statistics\_experienceav_byage.dta";
tab _merge;
tab _merge if age>=19;
drop _merge;
drop if age<19;

gen yEXP1 = EXP1/52;
gen yEXP7 = EXP7/(52*40);

gen yEXP1gr = 1 if yEXP1<=1;
replace yEXP1gr = 2 if yEXP1<=2 & yEXP1gr>1;
replace yEXP1gr = 3 if yEXP1<=3& yEXP1gr>2;
replace yEXP1gr = 4 if yEXP1<=4 & yEXP1gr>3;
replace yEXP1gr = 5 if yEXP1<=5 & yEXP1gr>4;
replace yEXP1gr = 6 if yEXP1<=6 & yEXP1gr>5;
replace yEXP1gr = 7 if yEXP1<=7 & yEXP1gr>6;
replace yEXP1gr = 8 if yEXP1<=8 & yEXP1gr>7;
replace yEXP1gr = 9 if yEXP1<=9 & yEXP1gr>8;
replace yEXP1gr = 10 if yEXP1<=10 & yEXP1gr>9;
replace yEXP1gr = 11 if yEXP1<=11 & yEXP1gr>10;
replace yEXP1gr = 12 if yEXP1<=12 & yEXP1gr>11;
replace yEXP1gr = 13 if yEXP1<=13 & yEXP1gr>12;
replace yEXP1gr = 14 if yEXP1<=14 & yEXP1gr>13;
replace yEXP1gr = 15 if yEXP1<=15 & yEXP1gr>14;
replace yEXP1gr = 16 if yEXP1<=16 & yEXP1gr>15;
replace yEXP1gr = 17 if yEXP1<=17 & yEXP1gr>16;
replace yEXP1gr = 18 if yEXP1<=18 & yEXP1gr>17;
replace yEXP1gr = 19 if yEXP1<=19 & yEXP1gr>18;
replace yEXP1gr = 20 if yEXP1<=20 & yEXP1gr>19;
replace yEXP1gr = 21 if yEXP1<=21 & yEXP1gr>20;
replace yEXP1gr = 22 if yEXP1<=22 & yEXP1gr>21;
replace yEXP1gr = 23 if yEXP1<=23 & yEXP1gr>22;
replace yEXP1gr = 24 if yEXP1<=24 & yEXP1gr>23;
replace yEXP1gr = 25 if yEXP1<=25 & yEXP1gr>24;
replace yEXP1gr = 26 if yEXP1<=26 & yEXP1gr>25;
replace yEXP1gr = 27 if yEXP1<=27 & yEXP1gr>26;
replace yEXP1gr = 28 if yEXP1<=28 & yEXP1gr>27;
replace yEXP1gr = 29 if yEXP1<=29 & yEXP1gr>28;
replace yEXP1gr = 30 if yEXP1<=30 & yEXP1gr>29;
replace yEXP1gr = 31 if yEXP1>30 ;

gen yEXP7gr = 1 if yEXP7<=1;
replace yEXP7gr = 2 if yEXP7<=2 & yEXP1gr>1;
replace yEXP7gr = 3 if yEXP7<=3 & yEXP1gr>2;
replace yEXP7gr = 4 if yEXP7<=4 & yEXP1gr>3;
replace yEXP7gr = 5 if yEXP7<=5 & yEXP1gr>4;
replace yEXP7gr = 6 if yEXP7<=6 & yEXP1gr>5;
replace yEXP7gr = 7 if yEXP7<=7 & yEXP1gr>6;
replace yEXP7gr = 8 if yEXP7<=8 & yEXP1gr>7;
replace yEXP7gr = 9 if yEXP7<=9 & yEXP1gr>8;
replace yEXP7gr = 10 if yEXP7<=10 & yEXP1gr>9;
replace yEXP7gr = 11 if yEXP7<=11 & yEXP1gr>10;
replace yEXP7gr = 12 if yEXP7<=12 & yEXP1gr>11;
replace yEXP7gr = 13 if yEXP7<=13 & yEXP1gr>12;
replace yEXP7gr = 14 if yEXP7<=14 & yEXP1gr>13;
replace yEXP7gr = 15 if yEXP7<=15 & yEXP1gr>14;
replace yEXP7gr = 16 if yEXP7<=16 & yEXP1gr>15;
replace yEXP7gr = 17 if yEXP7<=17 & yEXP1gr>16;
replace yEXP7gr = 18 if yEXP7<=18 & yEXP1gr>17;
replace yEXP7gr = 19 if yEXP7<=19 & yEXP1gr>18;
replace yEXP7gr = 20 if yEXP7<=20 & yEXP1gr>19;
replace yEXP7gr = 21 if yEXP7<=21 & yEXP1gr>20;
replace yEXP7gr = 22 if yEXP7<=22 & yEXP1gr>21;
replace yEXP7gr = 23 if yEXP7<=23 & yEXP1gr>22;
replace yEXP7gr = 24 if yEXP7<=24 & yEXP1gr>23;
replace yEXP7gr = 25 if yEXP7<=25 & yEXP1gr>24;
replace yEXP7gr = 26 if yEXP7<=26 & yEXP1gr>25;
replace yEXP7gr = 27 if yEXP7<=27 & yEXP1gr>26;
replace yEXP7gr = 28 if yEXP7<=28 & yEXP1gr>27;
replace yEXP7gr = 29 if yEXP7<=29 & yEXP1gr>28;
replace yEXP7gr = 30 if yEXP7<=30 & yEXP1gr>29;
replace yEXP7gr = 31 if yEXP7>30;

gen yX1g = 1 if yEXP1gr<5;
replace  yX1g = 2 if yEXP1gr>=5 & yEXP1gr<10;
replace  yX1g = 3 if yEXP1gr>=10 & yEXP1gr<15;
replace  yX1g = 4 if yEXP1gr>=15 & yEXP1gr<20;
replace  yX1g = 5 if yEXP1gr>=20 ;

gen yX7g = 1 if yEXP7gr<5;
replace  yX7g = 2 if yEXP7gr>=5 & yEXP7gr<10;
replace  yX7g = 3 if yEXP7gr>=10 & yEXP7gr<15;
replace  yX7g = 4 if yEXP7gr>=15 & yEXP7gr<20;
replace  yX7g = 5 if yEXP7gr>=20 ;

label define expv 1 "<5yrs" 2 "5-<10yrs" 3 "10-<15yrs" 4 "15-<20yrs" 5 ">=20yrs";
label values yX1g expv;
label values yX7g expv;

preserve;

keep if avHRP>low5 & avHRP<high5;
cap drop INC;
gen INC = 1 if SAMP<5;
replace INC = 2 if SAMP>=5;
label define INCv 1 "Male" 2 "Female";
label values INC INCv;
cap drop a;
gen a = 1;
	collapse (sum) a, by(hrpgroup INC yX1g);
	
	save "My Statistics\histograms\hist_hrp_2.dta", replace;
	sort INC yX1g;
	by INC yX1g: egen tot = sum(a);
	gen pc = a/tot*100;

	gen group = INC*10+yX1g;
	drop a tot INC yX1g;

	reshape i hrpgroup;
	reshape j group;
	reshape xij pc;
	reshape xi;
	reshape wide;

	label var pc11 "0-5";
	label var pc12 "5-10";
	label var pc13 "10-15";
	label var pc14 "15-20";
	label var pc15 ">20";

	label var pc21 "0-5";
	label var pc22 "5-10";
	label var pc23 "10-15";
	label var pc24 "15-20";
	label var pc25 ">20";

	graph pc11 pc12 pc13 pc14 pc15, bar by(hrpgroup) ylab 
		saving("My Statistics\histograms\hrphistm_2.gph", replace)
		ti("Men, HRP by experience");
	graph pc21 pc22 pc23 pc24 pc25, bar by(hrpgroup) ylab 
		saving("My Statistics\histograms\hrphistf_2.gph", replace)
		ti("Women, HRP by experience");


restore;
preserve;

keep if avHRP>low5 & avHRP<high5;
cap drop INC;
gen INC = 1 if SAMP<5;
replace INC = 2 if SAMP>=5;
label define INCv 1 "Male" 2 "Female";
label values INC INCv;
cap drop a;
gen a = 1;
	collapse (sum) a, by(hrpgroup INC yX7g);
	
	save "E:\RA\NLSY\My Statistics\hist_hrp_3.dta", replace;
	sort INC yX7g;
	by INC yX7g: egen tot = sum(a);
	gen pc = a/tot*100;

	gen group = INC*10+yX7g;
	drop a tot INC yX7g;

	reshape i hrpgroup;
	reshape j group;
	reshape xij pc;
	reshape xi;
	reshape wide;

	label var pc11 "0-5";
	label var pc12 "5-10";
	label var pc13 "10-15";
	label var pc14 "15-20";
	label var pc15 ">20";

	label var pc21 "0-5";
	label var pc22 "5-10";
	label var pc23 "10-15";
	label var pc24 "15-20";
	label var pc25 ">20";

	graph pc11 pc12 pc13 pc14 pc15, bar by(hrpgroup) ylab 
		saving("My Statistics\histograms\hrphistm_3.gph", replace)
		ti("Men, HRP by experience");
	graph pc21 pc22 pc23 pc24 pc25, bar by(hrpgroup) ylab 
		saving("My Statistics\histograms\hrphistf_3.gph", replace)
		ti("Women, HRP by experience");


restore;
** Note:  there are some instances of one weird observation screwing things up.  Am trying to deal with this here.
	For those with avHRP<lowest allowable, replace with maxHRP.  For those with avHRP>highest allowable, replace 
	with minHRP.  Very arbitrary.  But some really weird stuff otherwise;

replace avHRP = maxHRP if avHRP<=high5;
replace avHRP = maxHRP if avHRP<(maxHRP/2) & maxHRP<high5;
replace avHRP = minHRP if avHRP>=high5;

keep if avHRP>low5 & avHRP<high5;
gen INC = 1 if SAMP<5;
replace INC = 2 if SAMP>=5;
label define INCv 1 "Male" 2 "Female";
label values INC INCv;

cap drop a;
gen a = 1;


** Identifying individuals who have observations for given ages;
gen o19 = 1 if avHRP>0 & age == 19;
gen o20 = 1 if avHRP>0 & age == 20;
gen o21 = 1 if avHRP>0 & age == 21;
gen o22 = 1 if avHRP>0 & age == 22;
gen o23 = 1 if avHRP>0 & age == 23;
gen o24 = 1 if avHRP>0 & age == 24;
gen o25 = 1 if avHRP>0 & age == 25;
gen o26 = 1 if avHRP>0 & age == 26;
gen o27 = 1 if avHRP>0 & age == 27;
gen o28 = 1 if avHRP>0 & age == 28;
gen o29 = 1 if avHRP>0 & age == 29;
gen o30 = 1 if avHRP>0 & age == 30;
gen o31 = 1 if avHRP>0 & age == 31;
gen o32 = 1 if avHRP>0 & age == 32;
gen o33 = 1 if avHRP>0 & age == 33;
gen o34 = 1 if avHRP>0 & age == 34;
gen o35 = 1 if avHRP>0 & age == 35;
gen o36 = 1 if avHRP>0 & age == 36;
gen o37 = 1 if avHRP>0 & age == 37;
gen o38 = 1 if avHRP>0 & age == 38;
gen o39 = 1 if avHRP>0 & age == 39;
gen o40 = 1 if avHRP>0 & age == 40;
gen o41 = 1 if avHRP>0 & age == 41;

sort ID age;
by ID: egen eo19 = max(o19);
by ID: egen eo20 = max(o20);
by ID: egen eo21 = max(o21);
by ID: egen eo22 = max(o22);
by ID: egen eo23 = max(o23);
by ID: egen eo24 = max(o24);
by ID: egen eo25 = max(o25);
by ID: egen eo26 = max(o26);
by ID: egen eo27 = max(o27);
by ID: egen eo28 = max(o28);
by ID: egen eo29 = max(o29);
by ID: egen eo30 = max(o30);
by ID: egen eo31 = max(o31);
by ID: egen eo32 = max(o32);
by ID: egen eo33 = max(o33);
by ID: egen eo34 = max(o34);
by ID: egen eo35 = max(o35);
by ID: egen eo36 = max(o36);
by ID: egen eo37 = max(o37);
by ID: egen eo38 = max(o38);
by ID: egen eo39 = max(o39);
by ID: egen eo40 = max(o40);
by ID: egen eo41 = max(o41);

mvencode eo19 eo20 eo21 eo22 eo23 eo23 eo25 eo26 eo27 eo28 eo29 eo30
     eo31 eo32 eo33 eo34 eo35 eo36 eo37 eo38 eo39 eo40 eo41, mv(0);
** Generating variables identifying whether there is an observation on HRP for the 3 year intervals;
gen eo2022 = eo21+eo22+eo23;
gen eo2527 = eo25+eo26+eo27;
gen eo3032 = eo31+eo32+eo33;
gen eo3537 = eo35+eo36+eo37;



gen age20i = o20;

gen age21 = o21;
replace age21 = o20 if eo21==0;
replace age21 = o22 if eo21==0 & eo20==0;

gen age21i = o21;

gen age25i = o25;

gen age26 = o26;
replace age26 = o25 if eo26==0;
replace age26 = o27 if eo26==0 & eo24==0;

gen age26i = o26;

gen age30i = o30;

gen age31 = o31;
replace age31 = o30 if eo31==0;
replace age31 = o32 if eo31==0 & eo30==0;

gen age31i = o31;

gen age35i = o35;

gen age36 = o36;
replace age36 = o35 if eo36==0;
replace age36 = o37 if eo36==0 & eo35==0;

gen age36i = o36;

gen age40i = o40;



preserve;



*******************************************************************************************
*******************************************************************************************
*******************************************************************************************
The rest of the file calculates a lot of statistics that were not in the end used. Might be
of interest to somebody though.
*******************************************************************************************
*******************************************************************************************
*******************************************************************************************;




** so now I'm going to go through first and calculate returns from age 20-22 to age 35-37;
** choose a different agelow and agehigh for a different age range;

gen agelow = age21;
gen agehigh = age36;
gen agediff = 36-21;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


restore;

preserve;
** so now I'm going to go through first and calculate returns from age 20-22 to age 24-26;
** choose a different agelow and agehigh for a different age range;

gen agelow = age21;
gen agehigh = age26;
gen agediff = 26-21;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


restore;

preserve;
** so now I'm going to go through first and calculate returns from age 25-27 to age 30-32;
** choose a different agelow and agehigh for a different age range;

gen agelow = age26;
gen agehigh = age31;
gen agediff = 31-26;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


restore;

preserve;
** so now I'm going to go through first and calculate returns from age 30-32 to age 35-37;
** choose a different agelow and agehigh for a different age range;

gen agelow = age31;
gen agehigh = age36;
gen agediff = 36-31;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


restore;

preserve;


** so now I'm going to go through first and calculate returns from age 21 to age 36;
** choose a different agelow and agehigh for a different age range;

gen agelow = age25i;
gen agehigh = age36i;
gen agediff = 36-21;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


restore;

preserve;
** so now I'm going to go through first and calculate returns from age 21 to age 26;
** choose a different agelow and agehigh for a different age range;

gen agelow = age21i;
gen agehigh = age26i;
gen agediff = 26-21;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


restore;

preserve;
** so now I'm going to go through first and calculate returns from age 26 to age 31;
** choose a different agelow and agehigh for a different age range;

gen agelow = age26i;
gen agehigh = age31i;
gen agediff = 31-26;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


restore;

preserve;
** so now I'm going to go through first and calculate returns from age 31 to age 36;
** choose a different agelow and agehigh for a different age range;

gen agelow = age31i;
gen agehigh = age36i;
gen agediff = 36-31;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;
restore;

preserve;
** so now I'm going to go through first and calculate returns from age 20 to age 40;
** choose a different agelow and agehigh for a different age range;

gen agelow = age20i;
gen agehigh = age40i;
gen agediff = 40-20;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;
restore;

preserve;
** so now I'm going to go through first and calculate returns from age 20 to age 25;
** choose a different agelow and agehigh for a different age range;

gen agelow = age20i;
gen agehigh = age25i;
gen agediff = 25-20;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;
restore;
preserve;

** so now I'm going to go through first and calculate returns from age 25 to age 30;
** choose a different agelow and agehigh for a different age range;

gen agelow = age25i;
gen agehigh = age30i;
gen agediff = 30-25;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;
restore;
preserve;
** so now I'm going to go through first and calculate returns from age 30 to age 35;
** choose a different agelow and agehigh for a different age range;

gen agelow = age30i;
gen agehigh = age35i;
gen agediff = 35-30;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;restore;
preserve;

** so now I'm going to go through first and calculate returns from age 35 to age 40;
** choose a different agelow and agehigh for a different age range;

gen agelow = age35i;
gen agehigh = age40i;
gen agediff = 40-35;

gen HRPlow = agelow*avHRP;
gen HRPhigh = agehigh*avHRP;

by ID: egen RPlow = max(HRPlow);
by ID: egen RPhigh = max(HRPhigh);

** generate actual change in experience over this time;
by ID: egen EXP1al = max(yEXP1*agelow);
by ID: egen EXP1ah = max(yEXP1*agehigh);
gen dEXP1 = EXP1ah-EXP1al if agelow==1;

by ID: egen EXP7al = max(yEXP7*agelow);
by ID: egen EXP7ah = max(yEXP7*agehigh);
gen dEXP7 = EXP7ah-EXP7al if agelow==1;

gen rage = ((RPhigh/RPlow)^(1/agediff)-1)*100 if agelow==1;
sort sex;
by sex: sum rage;
kdensity rage if agelow==1, xlab;
graph rage, bin(20) xlab ylab;

gen rage1 = ((RPhigh/RPlow)^(1/dEXP1)-1)*100 if agelow==1;
sort sex;
by sex: sum rage1;
kdensity rage1 if agelow==1, xlab;
graph rage1 if rage1>-10 & rage1<20, bin(20) xlab ylab;

gen rage2 = ((RPhigh/RPlow)^(1/dEXP7)-1)*100 if agelow==1;
sort sex;
by sex: sum rage2;
kdensity rage2 if agelow==1, xlab;
graph rage2 if rage2>-10 & rage2<20, bin(20) xlab ylab;

sort sex age;
by sex age: egen r25 = pctile(rage), p(2.5);
by sex age: egen r975 = pctile(rage), p(97.5);
by sex age: egen r125 = pctile(rage1), p(2.5);
by sex age: egen r1975 = pctile(rage1), p(97.5);
by sex age: egen r225 = pctile(rage2), p(2.5);
by sex age: egen r2975 = pctile(rage2), p(97.5);

by sex: sum rage if rage<r975 & rage>r25;
by sex: sum rage1 if rage1<r1975 & rage1>r125;
by sex: sum rage2 if rage2<r2975 & rage2>r225;


graph rage if rage>r25 & rage<r975, bin(20) xlab ylab;
graph rage1 if rage1>r125 & rage1<r1975, bin(20) xlab ylab;
graph rage2 if rage2>r225 & rage2<r2975, bin(20) xlab ylab;

gen rr = 1 if rage<=-10;
replace rr = 2 if rage>-10 & rage<=-8.5;
replace rr = 3 if rage>-8.5 & rage<=-7;
replace rr = 4 if rage>-7 & rage<=-5.5;
replace rr = 5 if rage>-5.5 & rage<=-4;
replace rr = 6 if rage>-4 & rage<=2.5;
replace rr = 7 if rage>-2.5 & rage<=-1;
replace rr = 8 if rage>-1 & rage<=0.5;
replace rr = 9 if rage>0.5 & rage<=2;
replace rr = 10 if rage>2 & rage<=3.5;
replace rr = 11 if rage>3.5 & rage<=5;
replace rr = 12 if rage>5 & rage<=6.5;
replace rr = 13 if rage>6.5 & rage<=8;
replace rr = 14 if rage>8 & rage<=9.5;
replace rr = 15 if rage>9.5 & rage<=11;
replace rr = 16 if rage>11 & rage<=12.5;
replace rr = 17 if rage>12.5 & rage<=14;
replace rr = 18 if rage>14 & rage<=15.5;
replace rr = 19 if rage>15.5 & rage<=17;
replace rr = 20 if rage>17 & rage<=18.5;
replace rr = 21 if rage>18.5 & rage<10000;
replace rr = -100 if rage>=20000;

gen rr1 = 1 if rage1<=-10;
replace rr1 = 2 if rage1>-10 & rage1<=-8.5;
replace rr1 = 3 if rage1>-8.5 & rage1<=-7;
replace rr1 = 4 if rage1>-7 & rage1<=-5.5;
replace rr1 = 5 if rage1>-5.5 & rage1<=-4;
replace rr1 = 6 if rage1>-4 & rage1<=2.5;
replace rr1 = 7 if rage1>-2.5 & rage1<=-1;
replace rr1 = 8 if rage1>-1 & rage1<=0.5;
replace rr1 = 9 if rage1>0.5 & rage1<=2;
replace rr1 = 10 if rage1>2 & rage1<=3.5;
replace rr1 = 11 if rage1>3.5 & rage1<=5;
replace rr1 = 12 if rage1>5 & rage1<=6.5;
replace rr1 = 13 if rage1>6.5 & rage1<=8;
replace rr1 = 14 if rage1>8 & rage1<=9.5;
replace rr1 = 15 if rage1>9.5 & rage1<=11;
replace rr1 = 16 if rage1>11 & rage1<=12.5;
replace rr1 = 17 if rage1>12.5 & rage1<=14;
replace rr1 = 18 if rage1>14 & rage1<=15.5;
replace rr1 = 19 if rage1>15.5 & rage1<=17;
replace rr1 = 20 if rage1>17 & rage1<=18.5;
replace rr1 = 21 if rage1>18.5 & rage1<20000;
replace rr1 = -100 if rage1>=20000;

gen rr2 = 1 if rage2<=-10;
replace rr2 = 2 if rage2>-10 & rage2<=-8.5;
replace rr2 = 3 if rage2>-8.5 & rage2<=-7;
replace rr2 = 4 if rage2>-7 & rage2<=-5.5;
replace rr2 = 5 if rage2>-5.5 & rage2<=-4;
replace rr2 = 6 if rage2>-4 & rage2<=2.5;
replace rr2 = 7 if rage2>-2.5 & rage2<=-1;
replace rr2 = 8 if rage2>-1 & rage2<=0.5;
replace rr2 = 9 if rage2>0.5 & rage2<=2;
replace rr2 = 10 if rage2>2 & rage2<=3.5;
replace rr2 = 11 if rage2>3.5 & rage2<=5;
replace rr2 = 12 if rage2>5 & rage2<=6.5;
replace rr2 = 13 if rage2>6.5 & rage2<=8;
replace rr2 = 14 if rage2>8 & rage2<=9.5;
replace rr2 = 15 if rage2>9.5 & rage2<=11;
replace rr2 = 16 if rage2>11 & rage2<=12.5;
replace rr2 = 17 if rage2>12.5 & rage2<=14;
replace rr2 = 18 if rage2>14 & rage2<=15.5;
replace rr2 = 19 if rage2>15.5 & rage2<=17;
replace rr2 = 20 if rage2>17 & rage2<=18.5;
replace rr2 = 21 if rage2>18.5 & rage2<20000;
replace rr2 = -100 if rage2>=20000;


sort sex;
by sex:  tabstat rr if rr~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr1 if rr1~=-100, s(n mean sd max min p50 p5 p95) c(s);
by sex:  tabstat rr2 if rr2~=-100, s(n mean sd max min p50 p5 p95) c(s);

by sex: tab rr if rr~=-100;
by sex: tab rr1 if rr~=-100;
by sex: tab rr2 if rr~=-100;


gen dyX1g = 1 if dEXP1<5;
replace  dyX1g = 2 if dEXP1>=5 & dEXP1<10;
replace  dyX1g = 3 if dEXP1>=10 & dEXP1<15;
replace  dyX1g = 4 if dEXP1>=15 & dEXP1<20;
replace  dyX1g = 5 if dEXP1>=20 ;
replace dyX1g = -10 if dEXP1>100;

gen dyX7g = 1 if dEXP7<5;
replace  dyX7g = 2 if dEXP7>=5 & dEXP7<10;
replace  dyX7g = 3 if dEXP7>=10 & dEXP7<15;
replace  dyX7g = 4 if dEXP7>=15 & dEXP7<20;
replace  dyX7g = 5 if dEXP7>=20 ;
replace dyX7g = -10 if dEXP7>100;


label values dyX1g expv;
label values dyX7g expv;

sort dyX1g sex;
by dyX1g sex: tab rr if dyX1g>0;
by dyX1g sex: tab rr1 if dyX1g>0;
by dyX1g sex: tab rr2 if dyX1g>0;

sort dyX7g sex;
by dyX7g sex: tab rr if dyX7g>0;
by dyX7g sex: tab rr1 if dyX7g>0;
by dyX7g sex: tab rr2 if dyX7g>0;


log close;
