#delimit ;
set more off;
cd "E:\RA\NLSY\FINAL_FILES\";

** NOTE:  This is set up to identify a week as full time if a woman works 35 hours or more a week;

use "My Statistics\_weeklyfile2_women.dta", clear;

	do "Do\age_calc.do";


** Generating labour force status dummies;
** Dropping all weeks with unobserved labour force status.  This ensures that I don't 
include any observations from an individual whose labour force status in a given week is 
unobserved.  Since all numbers are positive otherwise, this simply means that I am not 
including in the experience calculation any value at all for weeks when we don't know 
the labour force status.  Should consider a little more how to deal with internal unknowns.
People are usually asked to fill in the gaps in known labour force status if they're not
interviewed one year, but there are still some gaps.;

	drop if lstatus==0;

** Generate a variable for employed or not;

       qui gen N = 1 if lstatus>100;
       replace N=0 if N~=1;

** Generate is is an indicator that hours weren't correctly reported;
       gen is = 1 if hrs<0;
       replace is = 0 if is~=1;
       gen hrs2 = hrs;
       replace hrs=0 if is==1;
       replace hrs2 = 40 if (hrs==0 & N==1);
	 replace hrs2 = 40 if is==1;

** Check that none of these has a negative value;
sum hrs hrs2 N;

       compress;
 
      drop lstatus;

** Need to change the value for hrs here if want to change the definition of full time;


gen FT1 = 1 if N==1 & hrs>=35;
replace FT1 = 0 if FT1~=1;
gen PT1 = 1 if N==1 & hrs<35;
replace PT1 = 1 if N==1 & is==1;
replace PT1 = 0 if PT1~=1;
gen FT2 = 1 if N==1 & hrs>=35;
replace FT2 = 1 if N ==1 & is==1;
replace FT2 = 1 if N==1 & hrs==0;
replace FT2 = 0 if FT2~=1;
gen PT2 = 1 if N==1 & hrs <35;
replace PT2 = 0 if N==1 & hrs==0;
replace PT2 = 0 if PT2~=1;

drop is;



** Combine with data on pre-1978 experience;
append using "My Statistics\pre_exp_summ_FT35.dta";


** Drop men merged in;
drop if SAMP<=4;

sort ID week;


** Generate the experience variables;
by ID: gen EXP1 = sum(N) + sum(pEXP1);
drop pEXP1 N;

by ID: gen EXP2 = sum(FT1) + sum(pEXP2);
drop pEXP2 FT1;

by ID: gen EXP3 = sum(PT1) + sum(pEXP3);
drop pEXP3 PT1;

by ID: gen EXP4 = sum(FT2) + sum(pEXP4);
drop pEXP4 FT2;

by ID: gen EXP5 = sum(PT2) + sum(pEXP5);
drop pEXP5 PT2;

by ID: gen EXP6 = sum(hrs) + sum(pEXP6);
drop pEXP6 hrs;

by ID: gen EXP7 = sum(hrs2) + sum(pEXP7);
drop pEXP7 hrs2;


drop if week==-100;
compress;

label var EXP1 "Weeks worked, av";
label var EXP2 "FT weeks, if is or 0 hrs, PT";
label var EXP3 "PT weeks, if is or 0 hrs, PT";
label var EXP4 "FT weeks, if is or 0 hrs, FT";
label var EXP5 "PT weeks, if is or 0 hrs, FT";
label var EXP6 "Total hours, if is or 0 hrs, 0 hrs";
label var EXP7 "Total hours, if is or 0 hrs, 40 hrs";


gen ageyownk1 = ageyownk;

sum EXP1 EXP2 EXP3 EXP4 EXP5 EXP6 EXP7;


replace EXP1 = -100 if EXP1<=0;
replace EXP2 = -100 if EXP2<=0;
replace EXP3 = -100 if EXP3<=0;
replace EXP4 = -100 if EXP4<=0;
replace EXP5 = -100 if EXP5<=0;
replace EXP6 = -100 if EXP6<=0;
replace EXP7 = -100 if EXP7<=0;

mvdecode EXP1 EXP2 EXP3 EXP4 EXP5 EXP6 EXP7, mv(-100);


save "My Statistics\experienceav_women.dta", replace;

collapse (min) ageyownk (mean) EXP1 EXP2 EXP3 EXP4 EXP5 EXP6 EXP7 (max) ageyownk1 SAMP nku6 nku18 everk nkborn, by(ID age);

 label var EXP1 "Experience in weeks, av during age specified";
 label var EXP2 "FT weeks, if is or 0 hrs, PT";
 label var EXP3 "PT weeks, if is or 0 hrs, PT";
 label var EXP4 "FT weeks, if is or 0 hrs, FT";
 label var EXP5 "PT weeks, if is or 0 hrs, FT";
 label var EXP6 "Total hours, if is or 0 hrs, 0 hrs";
 label var EXP7 "Total hours, if is or 0 hrs, 40 hrs";
 label var ageyownk "Age of youngest own child at age specified";
 label var nku6 "Maximum number of children under 6 during the year";
 label var nku18 "Maximum number of children under 18 during the year";
 sort ID age;

gen a1 = 0 if age<20;
replace a1 = 1 if age>=20 & age<25;
replace a1 = 2 if age>=25 & age<30;
replace a1 = 3 if age>=30 & age<35;
replace a1 = 4 if age>=35 & age<40;
replace a1 = 5 if age>=40 & age<45;
replace a1 = 6 if age>=45;
label values a1 a1v;


gen ay = 0;
replace ay = 1 if ageyownk<13 & ay==0;
replace ay = 2 if ageyownk<26 & ay==0;
replace ay = 3 if ageyownk<39 & ay==0;
replace ay = 4 if ageyownk<52 & ay==0;
replace ay = 5 if ageyownk<104 & ay==0;
replace ay = 6 if ageyownk<156 & ay==0;
replace ay = 7 if ageyownk<208 & ay==0;
replace ay = 8 if ageyownk<260 & ay==0;
replace ay = 9 if ageyownk<312 & ay==0;
replace ay =10 if ageyownk<364 & ay==0;
replace ay = 11 if ageyownk<936 & ay==0;

label define ayv 0 "None under 18" 1 "Under 1 qtr" 2 "1-2qtrs" 3 "2-3 qtrs" 4 "3-4 qtrs" 5 "1-2yrs" 6 "2-3yrs" 7 "3-4 yrs" 8 "4-5 yrs" 9 "5-6 yrs" 10 "6-7 yrs" 11 "7-18 yrs";
label values ay ayv;
label var ay "Age of youngest child";
sort ID age;

append using "My Statistics\experienceav_byage.dta"; 
sort ID age;


save "My Statistics\experienceav_byage.dta", replace;



