#delimit ;
set more off;

cd "E:\RA\NLSY\FINAL_FILES\";



**************************************************************************
**    This file calculates summary statistics of hours worked and		**
**	  rates of pay by individual and age.					**
**	It is a subroutine for _hrp_statistics.do					**
**	It calls on weekly_hrp.do							**
**************************************************************************
** Input files:  										**
**			_jobfile.dta							**
**			_weekly_hrp_*.dta							**
**												**
** Output files: 	hrp_intermediate_*.dta						**
**			hrp_byage_*.dta							**
**												**	
**												**
**												**
**************************************************************************;




** For men - merge this data on hours worked with the data in the file that identifies the job with the most
	hours worked per week, created from weekly_hrp.do;

** First create the weekly files (only have to do this once);
do "Do\weekly_hrp.do";
**;


use "My Statistics\_jobfile.dta";

	drop if SAMP>4;
	sort (ID JOB);
	merge (ID JOB) using "My Statistics\weekly_hrp_men.dta";
	tab _merge;

	drop if _merge == 1; *  These are jobs which are never the main job;
	sort ID week;
	sum ID;
	drop _merge;
	keep if SAMP==1|SAMP==2|SAMP==3|SAMP==4;

	sort ID week JOB;
	save "My Statistics\hrp_intermediate_men.dta", replace;

**** Do the same things for women;

	use "My Statistics\_jobfile.dta", clear;

	drop if SAMP<=4;
	sort (ID JOB);
	merge (ID JOB) using "My Statistics\weekly_hrp_women.dta";
	tab _merge;

	drop if _merge == 1; *  These are jobs which are never the main job;
	sort ID week;
	sum ID;
	drop _merge;
	keep if SAMP==5|SAMP==6|SAMP==7|SAMP==8;

	sort ID week JOB;
	save "My Statistics\hrp_intermediate_women.dta", replace;

**********************************************************************************;
** Now have two files (one for men, one for women) which include;
**	ID, SAMP, week (standard identifiers);
**	JN - the number of the job in the year (job number 1, 2, 3, 4 or 5);
**	NUMBER - the annual identifying number of the job in which the individual 
**			worked the most hours in that week(eg 101, 102, 1901);
**	HRP - the hourly rate of pay, nominal, in cents (ie 300 = $3);
**	mhrs - the hours worked in the job with the most hours that week;
**	thrs - the total hours worked in jobs 1-5 in that week (not working FOR SOME REASON just yet);
***********************************************************************************;
***  So now can (almost!) start doing the statistics on it;

** First run agecalc on it to allocate ages and years to the data;
	use "My Statistics\hrp_intermediate_men.dta", replace;

do "Do\age_calc.do";

compress;


** Collapse by age;
** First - make sure HRP is coded by STATA as missing, and deflate it;
** Note - deflation is based on year in which we observed the job, not year in which actually reported as working;
mvdecode HRP, mv(-5,-4,-3,-2,-1);
replace HRP = HRP/USCPI*100;
sum HRP;

** Now create new variables - for each year and individual, I'm going to calculate the mean median max and min wage **
** Because I've got missing values actually missing, the mean will be calculated as the average of all weeks in which **
** some wage was observed;
gen maxHRP = HRP;
gen minHRP = HRP;
gen medHRP = HRP;
gen avHRP = HRP;
sort ID age week;
collapse (mean) avHRP (max) maxHRP SAMP (min) minHRP (median) medHRP (count) HRP, by(ID age);
sort ID age;
sum avHRP medHRP;

save "My Statistics\hrp_men_byage.dta", replace;


**********************************************************************************************************************;
** Do the same thing for women;

** First run agecalc on it to allocate ages and years to the data;
	use "My Statistics\hrp_intermediate_women.dta", replace;

do "Do\age_calc.do";

compress;


** Collapse by age;
** First - make sure HRP is coded by STATA as missing, and deflate it;
** Note - deflation is based on year in which we observed the job, not year in which actually reported as working;
mvdecode HRP, mv(-5,-4,-3,-2,-1);
replace HRP = HRP/USCPI*100;

** Now create new variables - for each year and individual, I'm going to calculate the mean median max and min wage **
** Because I've got missing values actually missing, the mean will be calculated as the average of all weeks in which **
** some wage was observed;
gen maxHRP = HRP;
gen minHRP = HRP;
gen medHRP = HRP;
gen avHRP = HRP;
sort ID age week;
collapse (mean) avHRP (max) maxHRP SAMP (min) minHRP (median) medHRP (count) HRP, by(ID age);
sort ID age;

save "My Statistics\hrp_women_byage.dta", replace;
sum avHRP medHRP;
